﻿namespace Phoenix.Presenter.Managers
{
    using System.Collections.Generic;

    using Phoenix.Contracts;
    using Phoenix.Helpers.Misc;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal.Configuration;
    using Phoenix.Presenter.Manager;
    using Phoenix.View.Interfaces;

    /// <summary>
    /// Provides features to manage a FamilyLink    
    /// </summary>
    public class FamilyManager : Manager<FamilyLink>
    {
        #region Fields

        private IFamilyManager view;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="FamilyManager"/> class.
        /// </summary>
        /// <param name="view">The view.</param>
        public FamilyManager(IFamilyManager view)
            : base(Repositories.Get<IFamilyLinkRepository>())
        {
            this.view = view;
            this.view.Inserted += view_Inserted;
            this.view.Updated += view_Updated;
            this.view.Deleted += view_Deleted;
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Gets the family link types.
        /// </summary>
        /// <returns></returns>
        public IList<RelationType> GetFamilyLinkTypes()
        {
            SimpleFamilyLinkTypeManager rep = new SimpleFamilyLinkTypeManager();
            return rep.GetFamilyLinkTypes();
        }

        /// <summary>
        /// Gets the family of the specified patient.
        /// </summary>
        /// <param name="patient">The patient.</param>
        /// <returns>The list of all family member of the specified patient.</returns>
        public IList<FamilyLink> GetFamilyOf(Patient patient)
        {
            FamilyLink criterion = new FamilyLink();
            criterion.Member2 = patient;
            return base.Repository.Search(criterion);
        }

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <returns><c>True</c> if the data have passed the validation;
        /// otherwise <c>False</c></returns>
        public override bool ValidateData()
        {
            throw new System.NotImplementedException();
        }

        private void view_Deleted(object sender, EventArgs<FamilyLink> e)
        {
            FamilyLink familyLink = e.Value as FamilyLink;

            Contract.Requires((e.Value != null), "The family manager is expecting a family whose not null to be updatable");
            Contract.Requires((familyLink != null)
                , string.Format("The specified EventArgs contains a '{0}' while a 'FamilyLink' is expected!", e.Value.GetType().Name));
            Contract.Requires((familyLink.Member1 != familyLink.Member2), "You can't make a family link with a patient and him self");

            base.Delete(e.Value);
        }

        private void view_Inserted(object sender, EventArgs<FamilyLink> e)
        {
            FamilyLink familyLink = e.Value as FamilyLink;

            Contract.Requires((e.Value != null), "The family manager is expecting a family whose not null to be updatable");
            Contract.Requires((familyLink != null)
                , string.Format("The specified EventArgs contains a '{0}' while a 'FamilyLink' is expected!", e.Value.GetType().Name));
            Contract.Requires((familyLink.Member1 != familyLink.Member2), "You can't make a family link with a patient and him self");

            base.Insert(e.Value);
        }

        private void view_Updated(object sender, EventArgs<FamilyLink> e)
        {
            FamilyLink patient = e.Value as FamilyLink;

            Contract.Requires((e.Value != null), "The family manager is expecting a family whose not null to be updatable");
            Contract.Assert((patient != null)
                , string.Format("The specified EventArgs contains a '{0}' while a 'FamilyLink' is expected!", e.Value.GetType().Name));

            base.Update(patient);
        }

        #endregion Methods
    }
}