﻿namespace Phoenix.Model.Management
{
    using System.Collections.Generic;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces.Manager;

    /// <summary>
    /// Manage the family of a patient
    /// </summary>
    public class FamilyModel
    {
        #region Fields

        private IPatientRepository patientRepository = RepositoryFactory.Get<IPatientRepository>();
        private IFamilyManagerPresenter presenter;
        private IRelationRepository relationRepository = RepositoryFactory.Get<IRelationRepository>();
        private IRelationTypeRepository relationtypeRepository = RepositoryFactory.Get<IRelationTypeRepository>();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="FamilyModel"/> class.
        /// </summary>
        /// <param name="presenter">The view.</param>
        public FamilyModel(IFamilyManagerPresenter presenter)
        {
            this.presenter = presenter;
            this.presenter.RelationDeleted += (sender, e) =>
            {
                var patients = new List<Patient>()
                {
                    e.Data.UpsideDown.Member,
                    this.presenter.Patient
                };

                this.presenter.Patient.Remove(e.Data);
                this.patientRepository.Update(patients);
            };

            this.presenter.RelationInserted += (sender, e) =>
            {
                this.presenter.Patient.Add(e.Data);
                this.patientRepository.Update(this.presenter.Patient);

            };
            this.presenter.RelationUpdated += (sender, e) =>
            {
                //this.patientRepository.Update(this.view.Patient);
                this.relationRepository.Update(e.Data); //TODO It is more OO to update only the patient
            };
            this.presenter.Refreshed += (sender, e) => this.Refresh();
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <param name="relation">The relation.</param>
        /// <returns></returns>
        public bool ValidateData(Relation relation)
        {
            if (relation.Member == relation.UpsideDown.Member)
            {
                this.presenter.SetError(FamilyFailedOn.RecursiveRelation, "The two ends if the relation can't contain the same person!");
                return false;
            }
            return true;
        }

        /// <summary>
        /// Refreshes the data.
        /// </summary>
        private void Refresh()
        {
            this.presenter.RelationTypes = relationtypeRepository.GetAllRows();
            this.presenter.RefreshGui();
        }

        #endregion Methods
    }
}