﻿namespace Phoenix.Model.Management
{
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces.Manager;

    /// <summary>
    /// Implements all features to be a meeting manager
    /// </summary>
    public class MeetingModel
    {
        #region Fields

        private IWorkMeetingRepository meetingRepository = RepositoryFactory.Get<IWorkMeetingRepository>();
        private IPatientRepository patientRepository = RepositoryFactory.Get<IPatientRepository>();
        private IMeetingManagerPresenter presenter;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="MeetingModel"/> class.
        /// </summary>
        /// <param name="presenter">The view.</param>
        public MeetingModel(IMeetingManagerPresenter presenter)
        {
            this.presenter = presenter;
            this.presenter.Refreshed += (sender, e) => this.presenter.Meetings = this.meetingRepository.GetMeetings(this.presenter.Patient);

            this.presenter.Inserted += (sender, e) =>
            {
                WorkMeeting meeting = this.presenter.ItemToManage;

                Patient patient = this.presenter.Patient;
                patient.Add(meeting);

                this.patientRepository.Update(patient);
                this.presenter.RefreshGui();
            };

            this.presenter.Updated += (sender, e) =>
            {
                this.patientRepository.Update(this.presenter.Patient);
                this.presenter.RefreshGui();
            };

            this.presenter.Deleted += (sender, e) =>
            {
                WorkMeeting meeting = this.presenter.ItemToManage;

                Patient patient = this.presenter.Patient;
                patient.Remove(meeting);

                this.patientRepository.Update(patient);
                this.presenter.RefreshGui();
            };
        }

        #endregion Constructors
    }
}