﻿namespace Phoenix.Model.Core.Management
{
    using System;
    using System.Collections.Generic;
    using System.Linq;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces;

    /// <summary>
    /// Manage the business data of the meetings
    /// </summary>
    public class MeetingSideModel
    {
        #region Fields

        private IWorkMeetingRepository meetingRepository = RepositoryFactory.Get<IWorkMeetingRepository>();
        private IPatientRepository patientRepository = RepositoryFactory.Get<IPatientRepository>();
        private IMeetingSidePresenter presenter;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="MeetingSideModel"/> class.
        /// </summary>
        /// <param name="presenter">The presenter.</param>
        public MeetingSideModel(IMeetingSidePresenter presenter)
        {
            this.presenter = presenter;
            this.presenter.Refreshed += presenter_Refreshed;
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Gets the list patient that has meeting to the specified date.
        /// </summary>
        /// <param name="dateTime">The date time.</param>
        /// <returns></returns>
        public IList<Patient> GetPatientsFor(DateTime dateTime)
        {
            return (from meeting in this.meetingRepository.GetMeetings(dateTime)
                    orderby meeting.StartDate ascending
                    select meeting.Patient).ToList();
        }

        private void presenter_Refreshed(object sender, EventArgs e)
        {
            this.presenter.TodayMeetings = this.meetingRepository.GetMeetings(DateTime.Today);
        }

        #endregion Methods
    }
}