﻿namespace Phoenix.Model.Dal.Helpers
{
    using System;

    using NHibernate;
    using NHibernate.Cfg;

    using Phoenix.Contracts;

    /// <summary>
    /// Provides tools to ease the use of nHibernate.
    /// </summary>
    public static class OrmManager
    {
        #region Fields

        private static ISession session;

        #endregion Fields

        #region Properties

        public static ISessionFactory Factory
        {
            get;
            set;
        }

        /// <summary>
        /// Gets a value indicating whether this instance is open.
        /// </summary>
        /// <value><c>true</c> if this instance is open; otherwise, <c>false</c>.</value>
        public static bool IsOpen
        {
            get
            {
                return (Session != null && Session.IsOpen);
            }
        }

        /// <summary>
        /// Gets the Session.
        /// </summary>
        /// <value>The Session.</value>
        /// <exception cref="InvalidOperationException">If the Session is not loaded.</exception>
        public static ISession Session
        {
            get
            {
                if (session == null) throw new InvalidOperationException("Please load the nHibernate SessionManager before using it!");
                return session;
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Closes the session.
        /// </summary>
        /// <exception cref="InvalidOperationException">Thrown if session is not open or not instanciated.</exception>
        public static void CloseSession()
        {
            Assert.IsTrue((Session != null), "Impossible to close the session, it is 'null'!");
            Assert.IsTrue((Session.IsOpen == true), "Impossible to close the session, it is not open!");

            Session.Flush();
            Session.Close();
        }

        /// <summary>
        /// Configure the Session manager.
        /// </summary>
        public static void Initialize()
        {
            Configuration configuration = new Configuration();
            configuration.Configure().AddAssembly("Phoenix.Model.DAL");
            /*
             * If you have an exception complaining about an SQLite Driver not found
             * and you are running x64 OS, set the compilation of the project to 32bits
             */
            Factory = configuration.BuildSessionFactory();
            session = Factory.OpenSession();
        }

        #endregion Methods
    }
}