﻿namespace Phoenix.Model.Dal.Repositories
{
    using System.Linq;

    using NHibernate.Linq;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;

    public class UserRepository : Repository<User>, IUserRepository
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ReputationRepository"/> class.
        /// </summary>
        public UserRepository()
            : base("User", "LastName")
        {
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Gets the default user.
        /// </summary>
        /// <returns></returns>
        public User GetDefaultUser()
        {
            return (from User u in this.Session.Linq<User>()
                    where u.IsDefault == true
                    select u).FirstOrDefault();
        }

        /// <summary>
        /// Determines whether the specified item is referenced.
        /// It is never referenced.
        /// </summary>
        /// <param name="item">The item.</param>
        /// <returns>
        /// 	<c>true</c> if the specified item is referenced; otherwise, <c>false</c>.
        /// </returns>
        public override bool IsReferenced(User item)
        {
            return false;
        }

        #endregion Methods
    }
}