﻿namespace Phoenix.Presenter.Interfaces.Input
{
    using System;
    using System.Collections.Generic;

    using Phoenix.Model.Bll.Domain;

    #region Enumerations

    /// <summary>
    /// Indicates where the validation failed
    /// </summary>
    public enum KeywordGroupFailedOn
    {
        /// <summary>
        /// No keywords are linked to this group.
        /// </summary>
        NoKeywords,
        /// <summary>
        /// This keyword group does not have any title.
        /// </summary>
        NoTitle,
    }

    #endregion Enumerations

    /// <summary>
    /// View for a keyword manager
    /// </summary>
    public interface IKeywordInputPresenter
    {
        #region Events

        /// <summary>
        /// Occurs when a keyword group is deleted.
        /// </summary>
        event EventHandler Deleted;

        /// <summary>
        /// Occurs when a keyword group is added.
        /// </summary>
        event EventHandler Inserted;

        /// <summary>
        /// Occurs when keyword group is updated.
        /// </summary>
        event EventHandler Updated;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets or sets the item to manage.
        /// </summary>
        /// <value>The item to manage.</value>
        KeywordGroup ItemToManage
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the list keyword groups.
        /// </summary>
        /// <value>The keyword groups.</value>
        List<KeywordGroup> KeywordGroups
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Clears the invalidation error.
        /// </summary>
        void ClearError();

        /// <summary>
        /// Sets an error message to explain why data validation failed.
        /// </summary>
        /// <param name="failed">The fail.</param>
        /// <param name="message">The error message.</param>
        void Invalidate(KeywordGroupFailedOn failure, string errorMessage);

        #endregion Methods
    }
}