﻿namespace Phoenix.Test.Tools
{
    using System;
    using System.Collections.Generic;

    using NUnit.Framework;

    using Phoenix.Helpers.Misc;

    [TestFixture]
    public class EnumHelperTestSuite
    {
        #region Fields

        private const string DESCRIPTION = "With Description";

        #endregion Fields

        #region Enumerations

        public enum TestEnum
        {
            [System.ComponentModel.Description("With Description")]
            WithDescription,
            WithoutDescription,
        }

        #endregion Enumerations

        #region Methods

        [Test]
        public void CanTranslateAllEnumerations()
        {
            Dictionary<Enum, string> descriptions = EnumHelper.GetDescriptions(typeof(TestEnum));

            int descCount = descriptions.Count;
            int itemCount = EnumHelper.Count(typeof(TestEnum));
            Console.WriteLine("Descriptions: {0} - Items: {1}", descCount, itemCount);
            Assert.AreEqual(descCount, itemCount, "The count of expected items is wrong!");
        }

        [Test]
        public void CanTranslateEnumeration()
        {
            TestEnum predifined = TestEnum.WithoutDescription;

            string description = predifined.Description();

            Console.WriteLine("Description: {0}", description);

            Assert.IsFalse(string.IsNullOrEmpty(description),
                string.Format("The field '{0}' should have a value", predifined));

            Assert.IsTrue(description == "WithoutDescription", "The field should be equal to 'WithoutDescription'");

            /*****************************************/
            /*****************************************/
            /*****************************************/

            predifined = TestEnum.WithDescription;
            description = predifined.Description();

            Console.WriteLine("Description: {0}", description);

            Assert.IsFalse(string.IsNullOrEmpty(description),
                string.Format("The field '{0}' should have a value", predifined));

            Assert.IsTrue(description == DESCRIPTION, "The field should be equal to 'WithDescription'");
        }

        #endregion Methods
    }
}