﻿namespace Phoenix.View.Frame.Configuration
{
    using System;
    using System.Windows.Forms;

    using Phoenix.Presenter.Search;
    using Phoenix.Translation;
    using Phoenix.View.Configuration;

    /// <summary>
    /// Encapsulate the configuration of the search box
    /// </summary>
    public partial class SearchBoxConfigurationControl : UserControl, IConfigurationControl
    {
        #region Fields

        private AppearanceConfiguration searchBoxConfiguration = new AppearanceConfiguration();
        private string TipDefaultView = "The default view indicates how the searchbox displays the results in the window.".Translate();
        private string TipSplitteDistance = "The heigth of the criterion panel in the searchbox.".Translate();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="SearchBoxConfigurationControl"/> class.
        /// </summary>
        public SearchBoxConfigurationControl()
        {
            InitializeComponent();

            this.cb_DefaultView.DataSource = Enum.GetValues(typeof(SearchBox.SearchBoxView));
            this.cb_DefaultView.SelectedItem = this.searchBoxConfiguration.SearchBoxView;

            this.nud_SplitteDistance.Value = this.searchBoxConfiguration.PatientCriterionPanelHeight;

            this.tt_Tips.SetToolTip(this.cb_DefaultView, this.TipDefaultView);
            this.tt_Tips.SetToolTip(this.nud_SplitteDistance, this.TipSplitteDistance);

            this.tt_Tips.SetToolTip(this.lbl_DefaultView, this.TipDefaultView);
            this.tt_Tips.SetToolTip(this.lbl_SplitterDistance, this.TipSplitteDistance);

            this.lbl_DefaultView.Text = "Default view".Translate();
            this.lbl_SplitterDistance.Text = "Splitter distance".Translate();
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets the default view of the search box.
        /// </summary>
        /// <value>The default view.</value>
        public SearchBox.SearchBoxView DefaultView
        {
            get { return (SearchBox.SearchBoxView)this.cb_DefaultView.SelectedItem; }
        }

        /// <summary>
        /// Gets the heigth of the criterion panel.
        /// </summary>
        /// <value>The splitter distance.</value>
        public int SplitterDistance
        {
            get
            {
                return (int)this.nud_SplitteDistance.Value;
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Rollback theconfiguration date to the previous state.
        /// </summary>
        public void Rollback()
        {
            this.searchBoxConfiguration.Rollback();
        }

        /// <summary>
        /// Saves the configuration in the config file.
        /// </summary>
        public void SaveConfiguration()
        {
            this.searchBoxConfiguration.PatientCriterionPanelHeight = this.SplitterDistance;
            this.searchBoxConfiguration.SearchBoxView = this.DefaultView;
            this.searchBoxConfiguration.CommitChanges();
        }

        #endregion Methods
    }
}