﻿namespace Phoenix.View
{
    using System;

    using log4net;

    using Phoenix.Translation;

    using WeifenLuo.WinFormsUI.Docking;

    public class LogObject
    {
        #region Constructors

        public LogObject()
        {
            this.Logger = LogManager.GetLogger("Logget not loaded.");
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the logger.
        /// </summary>
        /// <value>The logger.</value>
        protected ILog Logger
        {
            get;
            set;
        }

        #endregion Properties
    }

    /// <summary>
    /// Root of all Form that implements translation
    /// </summary>
    public class TranslateableForm : DockContent
    {
        #region Fields

        private System.Windows.Forms.ContextMenuStrip cms_Context;
        private System.ComponentModel.IContainer components;
        private System.Windows.Forms.ToolStripMenuItem tsmi_Close;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="TranslateableForm"/> class.
        /// </summary>
        protected TranslateableForm()
        {
            this.Logger = LogManager.GetLogger("Logger not loaded.");
            this.InitializeComponent();

            base.HideOnClose = true;
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the logger.
        /// </summary>
        /// <value>The logger.</value>
        protected ILog Logger
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Centers the position of the form within the bounds of the parent form.
        /// </summary>
        public void MoveToParentCenter()
        {
            this.CenterToParent();
        }

        /// <summary>
        ///  Centers the form on the current screen.
        /// </summary>
        public void MoveToScreenCenter()
        {
            this.CenterToScreen();
        }

        /// <summary>
        /// Handles the error.
        /// </summary>
        /// <param name="ex">The ex.</param>
        protected void HandleError(Exception ex)
        {
            this.Logger.Error(ex);
        }

        /// <summary>
        /// Translates the form.
        /// </summary>
        protected void TranslateForm()
        {
            Translator.Translate(this);
        }

        private void InitializeComponent()
        {
            this.components = new System.ComponentModel.Container();
            this.cms_Context = new System.Windows.Forms.ContextMenuStrip(this.components);
            this.tsmi_Close = new System.Windows.Forms.ToolStripMenuItem();
            this.cms_Context.SuspendLayout();
            this.SuspendLayout();
            //
            // cms_Context
            //
            this.cms_Context.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
            this.tsmi_Close});
            this.cms_Context.Name = "cms_Context";
            this.cms_Context.Size = new System.Drawing.Size(104, 26);
            //
            // tsmi_Close
            //
            this.tsmi_Close.Name = "tsmi_Close";
            this.tsmi_Close.Size = new System.Drawing.Size(152, 22);
            this.tsmi_Close.Text = "Close";
            this.tsmi_Close.Click += new System.EventHandler(this.tsmi_Close_Click);
            //
            // TranslateableForm
            //
            this.ClientSize = new System.Drawing.Size(260, 55);
            this.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.HideOnClose = true;
            this.Name = "TranslateableForm";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.TabPageContextMenuStrip = this.cms_Context;
            this.Load += new System.EventHandler(this.TranslatedForm_Load);
            this.cms_Context.ResumeLayout(false);
            this.ResumeLayout(false);
        }

        private void TranslatedForm_Load(object sender, System.EventArgs e)
        {
            TranslateForm();
        }

        private void tsmi_Close_Click(object sender, EventArgs e)
        {
            this.Hide();
        }

        #endregion Methods
    }
}