﻿namespace Phoenix.Helpers.Winforms.Logging
{
    using System;
    using System.Collections.Generic;
    using System.Windows.Forms;

    using log4net;
    using log4net.Appender;
    using log4net.Core;
    using log4net.Repository.Hierarchy;

    /// <summary>
    /// Append the log into a ListView
    /// </summary>
    public class BasicTextBoxAppender : AppenderSkeleton
    {
        #region Fields

        private static TextBox _textBox;

        #endregion Fields

        #region Properties

        private static IAppender[] Appenders
        {
            get
            {
                List<IAppender> appenders = new List<IAppender>();
                var hierarchy = LogManager.GetRepository() as Hierarchy;

                appenders.AddRange(hierarchy.Root.Appenders.ToArray());
                foreach (var log in LogManager.GetCurrentLoggers())
                {
                    appenders.AddRange((log.Logger as Logger).Appenders.ToArray());
                }

                return appenders.ToArray();
            }
        }

        private TextBox TextBox
        {
            get { return _textBox; }
            set { _textBox = value; }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Configures this appender with the specified ListView.
        /// </summary>
        /// <param name="listView">The list view.</param>
        public static void Configure(TextBox textBox)
        {
            try
            {
                _textBox = textBox;

                foreach (var appender in Appenders)
                {
                    if (appender is BasicTextBoxAppender) (appender as BasicTextBoxAppender).TextBox = textBox;
                }
            }
            catch (Exception) { throw; }
        }

        /// <summary>
        /// Appends the specified logging event.
        /// </summary>
        /// <param name="loggingEvent">The logging event.</param>
        protected override void Append(LoggingEvent loggingEvent)
        {
            if (this.TextBox == null) return;

            if (this.TextBox.InvokeRequired) this.TextBox.Invoke((Action)delegate { Append(loggingEvent); });
            else this.Refresh(loggingEvent);
        }

        private void Refresh(LoggingEvent logEvent)
        {
            if (this.TextBox == null) return;
            this.TextBox.AppendText(string.Format("{0} {1}{2}"
                , logEvent.RenderedMessage
                , (logEvent.ExceptionObject == null) ? "" : logEvent.ExceptionObject.ToString()
                , Environment.NewLine));
        }

        #endregion Methods
    }
}