﻿namespace Phoenix.Helpers.Misc
{
    using System;
    using System.Diagnostics;

    /// <summary>
    /// Provides helpers to 
    /// </summary>
    public static class DateTimeHelper
    {
        #region Methods

        /// <summary>
        /// Gets the age of a person born at the specified birth date.
        /// </summary>
        /// <param name="birthDate">The birth date.</param>
        /// <returns>The age of the person</returns>
        [DebuggerStepThrough]
        public static int GetAge(this DateTime birthDate)
        {
            // cache the current time
            DateTime now = DateTime.Today; // today is fine, don't need the timestamp from now
            // get the difference in years
            int years = now.Year - birthDate.Year;
            // subtract another year if we're before the
            // birth day in the current year
            if (now.Month < birthDate.Month || (now.Month == birthDate.Month && now.Day < birthDate.Day))
                --years;

            return years;
        }

        /// <summary>
        /// Returns the data of the previous monday of the specified date.
        /// </summary>
        /// <param name="date">The date.</param>
        /// <returns>The data of the previous monday.</returns>
        //[DebuggerStepThrough]
        public static DateTime GetMonday(this DateTime date)
        {
            DateTime monday = new DateTime(date.Ticks);
            return monday.AddDays(-((int)date.DayOfWeek - 1));
        }

        /// <summary>
        /// Determines whether the specified dt has max value.
        /// </summary>
        /// <param name="dt">The dt.</param>
        /// <returns>
        /// 	<c>true</c> if is max value; otherwise, <c>false</c>.
        /// </returns>
        public static bool IsMaxValue(this DateTime dt)
        {
            return dt == DateTime.MaxValue;
        }

        /// <summary>
        /// Determines whether the specified dt has min value.
        /// </summary>
        /// <param name="dt">The dt.</param>
        /// <returns>
        /// 	<c>true</c> if is min value; otherwise, <c>false</c>.
        /// </returns>
        public static bool IsMinValue(this DateTime dt)
        {
            return dt == DateTime.MinValue;
        }

        /// <summary>
        /// Get the date of the first specified day.
        /// </summary>
        /// <param name="dt">The datetime.</param>
        /// <param name="startOfWeek">The start of week.</param>
        /// <returns>The DateTime with the start of week</returns>
        [DebuggerStepThrough]
        public static DateTime StartOfWeek(this DateTime dt, DayOfWeek startOfWeek)
        {
            int diff = dt.DayOfWeek - startOfWeek;
            if (diff < 0)
            {
                diff += 7;
            }

            return dt.AddDays(-1 * diff).Date;
        }

        #endregion Methods
    }
}