﻿namespace Phoenix.Helpers.Misc
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;

    /// <summary>
    /// Provides information about the current OS
    /// </summary>
    public static class OS
    {
        #region Properties

        /// <summary>
        /// Gets a value indicating whether this instance is windows 2000.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is windows2000; otherwise, <c>false</c>.
        /// </value>
        public static bool IsWindows2000
        {
            get { return IsVersion(5, 0); }
        }

        /// <summary>
        /// Gets a value indicating whether this instance is windows 2003.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is windows2003; otherwise, <c>false</c>.
        /// </value>
        public static bool IsWindows2003
        {
            get { return IsVersion(5, 2); }
        }

        /// <summary>
        /// Gets a value indicating whether this instance is windows 2003 RC2.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is windows2003 R c2; otherwise, <c>false</c>.
        /// </value>
        public static bool IsWindows2003RC2
        {
            get { return IsVersion(5, 2); }
        }

        /// <summary>
        /// Gets a value indicating whether this instance is windows2008.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is windows2008; otherwise, <c>false</c>.
        /// </value>
        public static bool IsWindows2008
        {
            get { return IsVersion(6, 0); }
        }

        /// <summary>
        /// Gets a value indicating whether this instance is windows2008 RC2.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is windows2008 R c2; otherwise, <c>false</c>.
        /// </value>
        public static bool IsWindows2008RC2
        {
            get { return IsVersion(6, 1); }
        }

        /// <summary>
        /// Gets a value indicating whether this instance is windows7.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is windows7; otherwise, <c>false</c>.
        /// </value>
        public static bool IsWindows7
        {
            get { return IsVersion(6, 1); }
        }

        /// <summary>
        /// Gets a value indicating whether this instance is windows vista.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is windows vista; otherwise, <c>false</c>.
        /// </value>
        public static bool IsWindowsVista
        {
            get { return IsVersion(6, 0); }
        }

        /// <summary>
        /// Gets a value indicating whether this instance is windows XP.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is windows XP; otherwise, <c>false</c>.
        /// </value>
        public static bool IsWindowsXP
        {
            get { return IsVersion(5, 1); }
        }

        /// <summary>
        /// Gets a value indicating whether this instance is windows XP 64 K.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is windows X P64 K; otherwise, <c>false</c>.
        /// </value>
        public static bool IsWindowsXP64K
        {
            get { return IsVersion(5, 2); }
        }

        #endregion Properties

        #region Methods

        private static bool IsVersion(int major, int minor)
        {
            OperatingSystem os = Environment.OSVersion;
            return (os.Version.Major == major && os.Version.Minor == minor);
        }

        #endregion Methods
    }
}